libclient

package
v0.0.0-...-ab61f1e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2024 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ReadContractJSON

func ReadContractJSON(file *string) (*core.Contract, error)

func ReadDFUJSON

func ReadDFUJSON(file *string) (*core.DFURegistry, error)

ReadDFUJSON reads the DFU information into a struct. IMPORTANT: JSON file does not contain the public keys so they should be added manually before sending the information to the registry

func ReadFSMJSON

func ReadFSMJSON(file *string) (*core.FSM, error)

func StoreDependencyValue

func StoreDependencyValue(c *core.Contract, wf string, txn string, input string,
	idx int, value string, file string) error

Types

This section is empty.

Jump to