Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func ReadDFUJSON ¶
func ReadDFUJSON(file *string) (*core.DFURegistry, error)
ReadDFUJSON reads the DFU information into a struct. IMPORTANT: JSON file does not contain the public keys so they should be added manually before sending the information to the registry
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.